CohereEmbeddingsModelOptions class

Options for Cohere embeddings models.

Inheritance

Constructors

CohereEmbeddingsModelOptions({int? dimensions, int? batchSize, String? inputType, List<String>? embeddingTypes, String? truncate})
Creates new Cohere embeddings model options.
const

Properties

batchSize int?
The maximum number of texts to embed in a single request.
finalinherited
dimensions int?
The number of dimensions the resulting output embeddings should have. Only supported by some models.
finalinherited
embeddingTypes List<String>?
The embedding types to return. Can include 'float', 'int8', 'uint8', 'binary', 'ubinary'.
final
hashCode int
The hash code for this object.
no setterinherited
inputType String?
The input type for the embeddings. Can be 'search_document', 'search_query', 'classification', 'clustering'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
truncate String?
How to handle inputs longer than the maximum token length. Can be 'NONE', 'START', 'END'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited