maxOutputTokens property
The maximum number of tokens to include in a candidate. If unset,
this will default to output_token_limit specified in the Model
specification.
Implementation
final int? maxOutputTokens;
The maximum number of tokens to include in a candidate. If unset,
this will default to output_token_limit specified in the Model
specification.
final int? maxOutputTokens;