LinkPart class final

A link part referencing external content.

Inheritance
Annotations
  • @immutable

Constructors

LinkPart(Uri url, {String? mimeType, String? name})
Creates a new link part.
const
LinkPart.fromJson(Map<String, Object?> json)
Creates a link part from a JSON-compatible map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
mimeType String?
Optional MIME type of the linked content.
final
name String?
Optional name for the link.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri
The URL of the external content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes the part to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String