MediaGenerationModel<TOptions extends MediaGenerationModelOptions> class abstract

Base class for media generation models.

Implementers

Constructors

MediaGenerationModel({required String name, required TOptions defaultOptions, List<Tool<Object>>? tools})
Creates a new media generation model instance.

Properties

defaultOptions → TOptions
The default options for the media generation model.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The model name to use.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<Tool<Object>>?
Optional tools that should be available to the media model.
final

Methods

dispose() → void
Disposes the media generation model.
generateMediaStream(String prompt, {required List<String> mimeTypes, List<ChatMessage> history = const [], List<Part> attachments = const [], TOptions? options, Schema? outputSchema}) Stream<MediaGenerationResult>
Generates media content as a stream of MediaGenerationResult chunks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited