topLogprobs property
An integer between 0 and 20 specifying the number of most likely tokens to return at each token position.
Implementation
final int? topLogprobs;
An integer between 0 and 20 specifying the number of most likely tokens to return at each token position.
final int? topLogprobs;