OpenAIResponsesMessageMapper class

Converts between dartantic chat messages and OpenAI Responses API payloads.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

log → Logger
Logger for message mapping operations.
final

Static Methods

mapHistory(List<ChatMessage> messages, {bool store = true, ImageDetail imageDetail = openai.ImageDetail.auto}) OpenAIResponsesHistorySegment
Maps the provided messages into an OpenAIResponsesHistorySegment understood by the Responses API.