XAIServerSideTool enum

xAI server-side tools for Responses calls.

Inheritance
Available extensions

Values

webSearch → const XAIServerSideTool

Web search tool.

xSearch → const XAIServerSideTool

X Search tool.

fileSearch → const XAIServerSideTool

File search tool.

codeInterpreter → const XAIServerSideTool

Code interpreter tool.

mcp → const XAIServerSideTool

Remote MCP tool.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<XAIServerSideTool>
A constant List of the values in this enum, in order of their declaration.