AnthropicChatModel class
Wrapper around Anthropic Messages API (aka Claude API).
- Inheritance
-
- Object
- ChatModel<
AnthropicChatOptions> - AnthropicChatModel
Constructors
-
AnthropicChatModel({required String name, required String apiKey, Uri? baseUrl, List<
Tool< ? tools, double? temperature, bool enableThinking = false, Client? client, Map<Object> >String, String> ? headers, AnthropicChatOptions? defaultOptions, List<String> betaFeatures = const [], bool? autoDownloadFiles}) - Creates a AnthropicChatModel instance.
Properties
- defaultOptions → AnthropicChatOptions
-
The default options for the chat model.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The model name to use.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature → double?
-
The temperature for the model.
finalinherited
-
tools
→ List<
Tool< ?Object> > -
The tools the model may call.
finalinherited
Methods
-
dispose(
) → void -
Disposes the chat model.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendStream(
List< ChatMessage> messages, {AnthropicChatOptions? options, Schema? outputSchema}) → Stream<ChatResult< ChatMessage> > -
Streaming method that returns Message objects.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited