GoogleFileSearchToolConfig class
Configuration for Gemini File Search (semantic retrieval from file stores).
- Annotations
-
- @immutable
Constructors
-
GoogleFileSearchToolConfig({required List<
String> fileSearchStoreNames, int? topK, String? metadataFilter}) -
Creates file search tool configuration.
const
Properties
-
fileSearchStoreNames
→ List<
String> -
Resource names of file search stores to query.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadataFilter → String?
-
Optional metadata filter expression for documents and chunks.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topK → int?
-
Optional number of semantic chunks to retrieve.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited