ThinkingEnabled class
Enables extended thinking with a token budget.
- Inheritance
-
- Object
- ThinkingConfig
- ThinkingEnabled
- Annotations
-
- @immutable
Constructors
- ThinkingEnabled({required int budgetTokens, ThinkingDisplayMode? display})
-
Creates a ThinkingEnabled.
const
-
ThinkingEnabled.fromJson(Map<
String, dynamic> json) -
Creates a ThinkingEnabled from JSON.
factory
Properties
- budgetTokens → int
-
Maximum tokens for thinking.
final
- display → ThinkingDisplayMode?
-
Controls how thinking content appears in the response.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? budgetTokens, Object? display = unsetCopyWithValue}) → ThinkingEnabled - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override