WebSearchOptions class
Web search options for the Chat Completions API.
This tool searches the web for relevant results to use in a response. Learn more about the web search tool.
- Annotations
-
- @immutable
Constructors
- WebSearchOptions({String? searchContextSize, WebSearchUserLocation? userLocation})
-
Creates WebSearchOptions.
const
-
WebSearchOptions.fromJson(Map<
String, dynamic> json) -
Creates WebSearchOptions from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchContextSize → String?
-
The amount of context to include from web search results.
final
- userLocation → WebSearchUserLocation?
-
The user's approximate location for localized search results.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override